
#headerR {
  position: absolute;
  right: 0px;
  width: 430px;
  height: 131px;
  background-image: url(top-right-kcontrol.png);
}

#title {
  right: 80px;
  font-size: x-large;
}

#tagline {
  right: 80px;
  font-size: x-small;
  text-shadow: #c8c8c8 0px 0px 3px;

}

#barCenter {
  font-size: x-small;
}

#tableTitle {
  font-weight: bold;
  padding-bottom: 1ex;
}

.kc_table {
  font-size: x-small;
  width: 100%;
}

.kc_leftcol {
  width: 30%;
}

.kc_rightcol {
  font-weight: bold;
}

.kc_use_text {
  margin-bottom: 0;
  font-size: xx-small;
}

.kcm_link {
  color: #000;
}

/* vim:set sw=2 et nocindent smartindent: */

